@@ -1,6 +1,7 @@
 import torch
 
-def batched_decode(loc, priors, variances):
+
+def batched_decode(loc, priors, variances, to_XYXY=True):
     """Decode locations from predictions using priors to undo
     the encoding we did for offset regression at train time.
     Args:
@@ -17,8 +18,9 @@ def batched_decode(loc, priors, variances):
         priors[:, :, :2] + loc[:, :, :2] * variances[0] * priors[:, :,  2:],
         priors[:, :, 2:] * torch.exp(loc[:, :, 2:] * variances[1])),
         dim=2)
-    boxes[:, :, :2] -= boxes[:, :, 2:] / 2
-    boxes[:, :, 2:] += boxes[:, :, :2]
+    if to_XYXY:
+        boxes[:, :, :2] -= boxes[:, :, 2:] / 2
+        boxes[:, :, 2:] += boxes[:, :, :2]
     return boxes
 
 
