@@ -43,10 +43,11 @@ class RetinaNetDetector(Detector):
         self.cfg = cfg
         self.net = net.to(self.device)
         self.mean = np.array([104, 117, 123], dtype=np.float32)
+        self.prior_box_cache = {}
 
-    def detect_with_landmarks(
+    def batched_detect_with_landmarks(
             self, image: np.ndarray) -> typing.Tuple[np.ndarray, np.ndarray]:
-        """Takes N images and performs and retunrs a set of bounding boxes as
+        """Takes N images and performs and returns a set of bounding boxes as
             detections
         Args:
             image (np.ndarray): shape [N, height, width, 3]
@@ -56,8 +57,9 @@ class RetinaNetDetector(Detector):
         """
         image = image.astype(np.float32) - self.mean
         image = np.moveaxis(image, -1, 1)
-        image = torch.from_numpy(image).to(self.device)
-        height, width = image.shape[2:]
+        image = torch.from_numpy(image)
+        orig_shape = image.shape[2:]
+        image = self.resize(image, 1).to(self.device)
         boxes, landms = self._detect(image, return_landmarks=True)
         scores = boxes[:, :, -1]
         boxes = boxes[:, :, :-1]
@@ -79,8 +81,12 @@ class RetinaNetDetector(Detector):
             scores_ = scores_[keep_idx]
             landms_ = landms_[keep_idx]
             # Scale boxes
+            height, width = orig_shape
+            if self.clip_boxes:
+                boxes_ = boxes_.clamp(0, 1)
             boxes_[:, [0, 2]] *= width
             boxes_[:, [1, 3]] *= height
+
             # Scale landmarks
             landms_ = landms_.cpu().numpy().reshape(-1, 5, 2)
             landms_[:, :, 0] *= width
@@ -102,18 +108,23 @@ class RetinaNetDetector(Detector):
             boxes: list of length N with shape [num_boxes, 5] per element
         """
         image = image[:, [2, 1, 0]]
-        loc, conf, landms = self.net(image)  # forward pass
-        scores = conf[:, :, 1:]
-        height, width = image.shape[2:]
-        priorbox = PriorBox(
-            self.cfg, image_size=(height, width))
-        priors = priorbox.forward()
-        priors = torch_utils.to_cuda(priors, self.device)
-        prior_data = priors.data
-        boxes = batched_decode(loc, prior_data, self.cfg['variance'])
-        landms = decode_landm(landms, prior_data, self.cfg['variance'])
-        boxes = torch.cat((boxes, scores), dim=-1)
+        with torch.cuda.amp.autocast(enabled=self.fp16_inference):
+            loc, conf, landms = self.net(image)  # forward pass
+            scores = conf[:, :, 1:]
+            height, width = image.shape[2:]
+            if image.shape[2:] in self.prior_box_cache:
+                priors = self.prior_box_cache[image.shape[2:]]
+            else:
+                priorbox = PriorBox(
+                    self.cfg, image_size=(height, width))
+                priors = priorbox.forward()
+                self.prior_box_cache[image.shape[2:]] = priors
+            priors = torch_utils.to_cuda(priors, self.device)
+            prior_data = priors.data
+            boxes = batched_decode(loc, prior_data, self.cfg['variance'])
+            boxes = torch.cat((boxes, scores), dim=-1)
         if return_landmarks:
+            landms = decode_landm(landms, prior_data, self.cfg['variance'])
             return boxes, landms
         return boxes
 
