@@ -60,7 +60,7 @@ class RetinaFace(nn.Module):
             backbone = MobileNetV1()
         elif cfg['name'] == 'Resnet50':
             import torchvision.models as models
-            backbone = models.resnet50(pretrained=cfg['pretrain'])
+            backbone = models.resnet50(pretrained=False)
 
         self.body = _utils.IntermediateLayerGetter(backbone, cfg['return_layers'])
         in_channels_stage2 = cfg['in_channel']
@@ -115,8 +115,5 @@ class RetinaFace(nn.Module):
             [self.ClassHead[i](feature) for i, feature in enumerate(features)],dim=1)
         ldm_regressions = torch.cat(
             [self.LandmarkHead[i](feature) for i, feature in enumerate(features)], dim=1)
-        if self.training:
-            output = (bbox_regressions, classifications, ldm_regressions)
-        else:
-            output = (bbox_regressions, classifications.softmax(dim=-1), ldm_regressions)
-        return output
\ No newline at end of file
+
+        return (bbox_regressions, classifications.softmax(dim=-1), ldm_regressions)
\ No newline at end of file
