@@ -2,11 +2,11 @@ import numpy as np
 import torch
 
 
-def to_cuda(elements):
+def to_cuda(elements, device):
     if torch.cuda.is_available():
         if type(elements) == tuple or type(elements) == list:
-            return [x.to(get_device()) for x in elements]
-        return elements.to(get_device())
+            return [x.to(device) for x in elements]
+        return elements.to(device)
     return elements
 
 
@@ -16,14 +16,12 @@ def get_device():
     return torch.device("cpu")
 
 
-def image_to_torch(image, cuda=True):
+def image_to_torch(image, device):
     if image.dtype == np.uint8:
         image = image.astype(np.float32)
     else:
         assert image.dtype == np.float32
     image = np.rollaxis(image, 2)
     image = image[None, :, :, :]
-    image = torch.from_numpy(image)
-    if cuda:
-        image = to_cuda(image)
+    image = torch.from_numpy(image).to(device)
     return image
